# Auditd Ripper
A Python CLI app that normalizes, aggregates, decodes, and exports auditd logs to a JSON file.

Example use:
```
pip install auditd-ripper
auditdr -i '/var/log/audit/auditd.log' -o '~/auditd.json'
```
